#!/usr/bin/env python
# -*- coding: utf-8 -*-

# ==============================================================================
# author          :Ghislain Vieilledent
# email           :ghislain.vieilledent@cirad.fr, ghislainv@gmail.com
# web             :https://ecology.ghislainv.fr
# python_version  :>=2.7
# license         :GPLv3
# ==============================================================================

import sys

import pywdpa
from .get_wdpa import get_wdpa


def main():
    """
    pywdpa.pywdpa: provides entry point main().
    """
    isocode = sys.argv[1]
    print(pywdpa.__doc__)
    print(f"version {pywdpa.__version__}.")
    print(f"Country isocode: {isocode}.")
    get_wdpa(isocode)


# End



"""
pywdpa: Easy access to world's protected areas.
https://ecology.ghislainv.fr/pywdpa/
"""

# Define double undescore variables
# https://peps.python.org/pep-0008/#module-level-dunder-names
__author__ = "Ghislain Vieilledent"
__email__ = "ghislain.vieilledent@cirad.fr"
__version__ = "0.1.6"

# GDAL exceptions
from osgeo import gdal

from .get_token import get_token
from .get_wdpa import get_wdpa

# GDAL exceptions
gdal.UseExceptions()

# End



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# ==============================================================================
# author          :Ghislain Vieilledent
# email           :ghislain.vieilledent@cirad.fr, ghislainv@gmail.com
# web             :https://ecology.ghislainv.fr
# python_version  :>=2.7
# license         :GPLv3
# ==============================================================================

# Import
from pywdpa import get_token


# test_get_token
def test_get_token():
    token = get_token(key="")
    msg = ("Missing WDPA API token. Please ensure that:{sep}"
           "1) You completed this form [https://api.protectedplanet.net/request] "
           "to get the token.{sep}"
           "2) You stored the value as an environment variable with the "
           "recommended name WDPA_KEY.").format(sep="\n")
    assert token == msg

# End



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# ==============================================================================
# author          :Ghislain Vieilledent
# email           :ghislain.vieilledent@cirad.fr, ghislainv@gmail.com
# web             :https://ecology.ghislainv.fr
# python_version  :>=2.7
# license         :GPLv3
# ==============================================================================

# Import
import os
import requests


# get_token()
def get_token(key="WDPA_KEY"):
    r"""Check Protected Planet API token.

    This function checks if the user has stored a valid Protected
    Planet API token as an environment variable file under the
    key ``"WDPA_KEY"``\ .

    Before using this package for the first time, the user must follow
    these steps:

    #. Fill in the form available at `<https://api.protectedplanet.net/request>`_
       to obtain a personal API token.
    #. Store the token as an environment variable under the key "WDPA_KEY".
       You can use the command ``os.environ["WDPA_KEY"]="your_token"`` or
       python-dotenv: `<https://github.com/theskumar/python-dotenv>`_.

    :param key: Environment variable name (recommended name: ``"WDPA_KEY"``\ ).

    :return: A vector of length one with the value of the API token.

    """

    wdpa_key = os.getenv(key)

    if wdpa_key is None:
        msg = ("Missing WDPA API token. Please ensure that:{sep}"
               "1) You completed this form [https://api.protectedplanet.net/request] "
               "to get the token.{sep}"
               "2) You stored the value as an environment variable with the "
               "recommended name WDPA_KEY.").format(sep="\n")
        return msg

    response = requests.get("https://api.protectedplanet.net/"
                            f"test?token={wdpa_key}", timeout=None)

    if response.status_code == 401:
        msg = ("Invalid WDPA API token. Please ensure that:{sep}"
               "1) You completed this form [https://api.protectedplanet.net/request] "
               "to get the token.{sep}"
               "2) You stored the value as an environment variable with the "
               "recommended name WDPA_KEY.").format(sep="\n")
        return msg

    if response.status_code != 200:
        return "Something goes wrong with your API token."

    return wdpa_key

# End



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Installation setup."""

# ================================================================
# author          :Ghislain Vieilledent
# email           :ghislain.vieilledent@cirad.fr
# web             :https://ecology.ghislainv.fr
# python_version  :>=3.6
# license         :GPLv3
# ================================================================

# Import
import io
import re  # Regular expression
from setuptools import setup


# find_version
def find_version():
    """Finding package version."""
    with open("pywdpa/__init__.py", encoding="utf-8") as init_file:
        init_text = init_file.read()
    _version = (re.search('^__version__\\s*=\\s*"(.*)"',
                          init_text, re.M)
                .group(1))
    return _version


version = find_version()

# reStructuredText README file
with io.open("README.rst", encoding="utf-8") as f:
    long_description = f.read()

# Project URLs
project_urls = {
    'Documentation': 'https://ecology.ghislainv.fr/pywdpa',
    'Source': 'https://github.com/ghislainv/pywdpa/',
    'Traker': 'https://github.com/ghislainv/pywdpa/issues',
}

# Setup
setup(name="pywdpa",
      version=version,
      author="Ghislain Vieilledent",
      author_email="ghislain.vieilledent@cirad.fr",
      url="https://ecology.ghislainv.fr/pywdpa",
      project_urls=project_urls,
      license="GPLv3",
      description="Easy access to world's protected areas",
      long_description=long_description,
      long_description_content_type="text/x-rst",
      classifiers=["Development Status :: 4 - Beta",
                   "License :: OSI Approved :: GNU General Public License v3 "
                   "(GPLv3)",
                   "Programming Language :: Python :: 3",
                   "Operating System :: OS Independent",
                   "Topic :: Scientific/Engineering :: Bio-Informatics"],
      keywords="protected areas wdpa world database protected areas",
      python_requires=">=3.6",
      packages=["pywdpa"],
      package_dir={"pywdpa": "pywdpa"},
      entry_points={"console_scripts": ["pywdpa = pywdpa.pywdpa:main"]},
      install_requires=["numpy", "gdal", "requests"],
      extras_require={
          "interactive": ["jupyter", "python-dotenv", "geopandas",
                          "descartes", "folium"]},
      zip_safe=False)

# End
